@@ -13,15 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import uuid
+from oslo_utils import uuidutils
 
 from oslo_middleware import base
 
 
-class CorrelationId(base.Middleware):
+class CorrelationId(base.ConfigurableMiddleware):
     "Middleware that attaches a correlation id to WSGI request"
 
     def process_request(self, req):
         correlation_id = (req.headers.get("X_CORRELATION_ID") or
-                          str(uuid.uuid4()))
+                          uuidutils.generate_uuid())
         req.headers['X_CORRELATION_ID'] = correlation_id
