@@ -15,6 +15,8 @@
 
 import collections
 import gc
+import io
+import ipaddress
 import json
 import platform
 import socket
@@ -26,7 +28,6 @@ import jinja2
 from oslo_utils import reflection
 from oslo_utils import strutils
 from oslo_utils import timeutils
-import six
 import stevedore
 import webob.dec
 import webob.exc
@@ -65,6 +66,12 @@ class Healthcheck(base.ConfigurableMiddleware):
       the activity of the server.
     * *(and more)*
 
+    .. note::
+
+        This middleware indicates that the API is accessible but it does
+        indicate that it is necessarily functional or that any other API
+        request will actually work.
+
     Example requests/responses (**not** detailed mode)::
 
       $ curl -i -X HEAD "http://0.0.0.0:8775/healthcheck"
@@ -385,6 +392,11 @@ Reason
                                      group='healthcheck')
         self._path = self._conf_get('path')
         self._show_details = self._conf_get('detailed')
+        self._source_ranges = [
+            ipaddress.ip_network(r)
+            for r in self._conf_get('allowed_source_ranges')]
+        self._ignore_proxied_requests = self._conf_get(
+            'ignore_proxied_requests')
         self._backends = stevedore.NamedExtensionManager(
             self.NAMESPACE, self._conf_get('backends'),
             name_order=True, invoke_on_load=True,
@@ -395,7 +407,7 @@ Reason
             ('text/html', self._make_html_response),
             ('application/json', self._make_json_response),
         ])
-        self._accept_order = tuple(six.iterkeys(self._accept_to_functor))
+        self._accept_order = tuple(self._accept_to_functor)
         # When no accept type matches instead of returning 406 we will
         # always return text/plain (because sending an error from this
         # middleware actually can cause issues).
@@ -437,8 +449,8 @@ Reason
         except AttributeError:
             pass
         else:
-            buf = six.StringIO()
-            for stack in six.itervalues(active_frames):
+            buf = io.StringIO()
+            for stack in active_frames.values():
                 traceback.print_stack(stack, file=buf)
                 threadstacks.append(buf.getvalue())
                 buf.seek(0)
@@ -449,7 +461,7 @@ Reason
     def _get_greenstacks():
         greenstacks = []
         if greenlet is not None:
-            buf = six.StringIO()
+            buf = io.StringIO()
             for gt in _find_objects(greenlet.greenlet):
                 traceback.print_stack(gt.gr_frame, file=buf)
                 greenstacks.append(buf.getvalue())
@@ -544,6 +556,24 @@ Reason
     def process_request(self, req):
         if not self._ignore_path and req.path != self._path:
             return None
+
+        if self._source_ranges:
+            remote_addr = ipaddress.ip_address(req.remote_addr)
+            for r in self._source_ranges:
+                if r.version == remote_addr.version and remote_addr in r:
+                    break
+            else:
+                # Because source ip is not included in allowed ranges, ignore
+                # the request in this middleware.
+                return None
+
+        if self._ignore_proxied_requests:
+            for hdr in [
+                'FORWARDED', 'FORWARDED_PROTO', 'FORWARDED_HOST',
+                'FORWARDED_FOR', 'FORWARDED_PREFIX']:
+                if req.environ.get("HTTP_X_%s" % hdr):
+                    return None
+
         results = [ext.obj.healthcheck(req.server_port)
                    for ext in self._backends]
         healthy = self._are_results_healthy(results)
